@@ -3,7 +3,9 @@
 cur_board = -1
 cur_serial_port = -1
 cur_iter = -1
-cur_font = -1
+cur_editor_font = -1
+cur_console_font = -1
 build_verbose = -1
 user_library = -1
 serial_baud_rate = -1
+show_numbers = -1
