@@ -24,6 +24,7 @@ import subprocess
 import select
 import shutil
 import signal
+import time
 
 import gettext
 _ = gettext.gettext
@@ -162,11 +163,11 @@ def processFile(f):
 	if page.get_data("label").get_text() == "Untitled":
 		replacePage(page)
 
-def saveAs():
+def saveAs(js=False):
 	page = getCurrentPage()
 	buf = page.get_data("buffer")
 	f = page.get_data("file")
-	if misc.bufferModified(buf, f) is False:
+	if misc.bufferModified(buf, f) is False and js is False:
 		return
 	p = gtk.FileChooserDialog("Save file", None, gtk.FILE_CHOOSER_ACTION_SAVE,
 		(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
@@ -205,7 +206,7 @@ def csave(w, data=None):
 	b = page.get_data("buffer")
 	f = page.get_data("file")
 	if f == None or data == True:
-		f = saveAs()
+		f = saveAs(data)
 		if f == None: return False
 		else:
 			if os.path.exists(f):
@@ -266,6 +267,9 @@ def butSave(widget, data=None):
 def menuUpload(widget, data=None):
 	upload(widget, ser, data)
 
+def menuReference(widget, data=None):
+	gtk.show_uri(None, "file:///"+os.path.join(misc.getArduinoFile("reference"), "index.html"), int(time.time()))
+
 def about(widget, data=None):
 	about = gui.get_object("about")
 	about.set_version(gnoduino.__version__)
@@ -433,6 +437,7 @@ menus = [
 		("menu-reset-board", menuResetBoard, (ord('m'), gtk.gdk.CONTROL_MASK)),
 		("menu-preferences", preferences, (None, None)),
 		("menu-upload", menuUpload, (ord('u'), gtk.gdk.CONTROL_MASK)),
+		("menu-reference", menuReference, (None, None)),
 		("menu-about", about, (None, None)),
 
 	]
@@ -468,6 +473,7 @@ def createScon():
 	sw.set_shadow_type(gtk.SHADOW_IN)
 	tmp = gtk.TextView()
 	tmp.set_editable(False)
+	tmp.set_wrap_mode(gtk.WRAP_WORD)
 	twbuf = gtk.TextBuffer()
 	tmp.set_buffer(twbuf)
 	tmp.modify_base(gtk.STATE_NORMAL, gtk.gdk.Color(0,0,0))
@@ -554,7 +560,7 @@ def cb_configure_event(widget, event):
 	p.saveValues()
 
 def vbox_move_handle(widget, scrolltype):
-	p.setValue("console.height", widget.get_position())
+	p.setValue("console.height", widget.get_position()+8)
 	p.saveValues()
 	return True
 
@@ -604,8 +610,8 @@ def run():
 					raise SystemExit(_("Cannot load ui file"))
 		mainwin = gui.get_object("top_win")
 		mainwin.set_icon_from_file(misc.getPixmapPath("gnoduino.png"))
-		mw = int(p.getSafeValue("default.window.width", 0))
-		mh = int(p.getSafeValue("default.window.height", 0))
+		mw = int(p.getSafeValue("default.window.width", 640))
+		mh = int(p.getSafeValue("default.window.height", 480))
 		if (mw and mh):
 			mainwin.set_default_size(mw, mh)
 		mainwin.connect("configure-event", cb_configure_event)
@@ -630,6 +636,7 @@ def run():
 			sub.append(menuItem)
 		gui.get_object("board").set_submenu(sub)
 		(con, tw) = createCon()
+		misc.setConsoleTags(tw)
 
 		"""setup default serial port"""
 		sub = gtk.Menu()
@@ -680,10 +687,9 @@ def run():
 		nb = gtk.Notebook()
 		nb.connect("switch-page", setupPage)
 		sv = createPage(nb)
-		vbox.add(nb)
-
+		vbox.pack1(nb, shrink=True, resize=True)
 		(scon,sctw) = createScon()
-		vbox.add(con)
+		vbox.pack2(con, shrink=False, resize=False)
 		vbox.connect("notify::position", vbox_move_handle)
 		cpos = int(p.getSafeValue("console.height", -1))
 		vbox.set_position(cpos)
